@@ -42,11 +42,12 @@ use SNMP::Info;
 
 use vars qw/$VERSION $DEBUG %MIBS %FUNCS %GLOBALS %MUNGE $INIT/;
 
-$VERSION = '3.52';
+$VERSION = '3.53';
 
 %MIBS = (
     'BRIDGE-MIB'   => 'dot1dBaseBridgeAddress',
     'Q-BRIDGE-MIB' => 'dot1qPvid',
+    'RSTP-MIB'     => 'dot1dStpPortOperEdgePort',
 );
 
 %GLOBALS = (
@@ -104,6 +105,10 @@ $VERSION = '3.52';
     'stp_p_bridge'   => 'dot1dStpPortDesignatedBridge',
     'stp_p_port'     => 'dot1dStpPortDesignatedPort',
 
+    # Rapid Spanning Tree Protocol Table : dot1dStpExtPortEntry
+    'is_edgeport_admin' => 'dot1dStpPortAdminEdgePort',
+    'is_edgeport_oper'  => 'dot1dStpPortOperEdgePort',
+
     # Q-BRIDGE-MIB : dot1qPortVlanTable
     'qb_i_vlan'        => 'dot1qPvid',
     'qb_i_vlan_type'   => 'dot1qPortAcceptableFrameTypes',
